.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

plugins.builtin
===============

.. toctree::
   :maxdepth: 1

   addcommand
   addoption
   capture
   email
   html
   json
   junit
   markdown
   post_clean
   pyt
   repeat
   testcase_generator
